<?php

	/**
	 * French Language file for phpPgAdmin. 
	 * @maintainer Pascal PEYRE [pascal.peyre@cir.fr]
	 *
	 * $Id: french.php,v 1.14 2004/11/09 01:57:50 chriskl Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Franais';
	$lang['appcharset'] = 'ISO-8859-1';
	$lang['applocale'] = 'fr_FR';
  	$lang['appdbencoding'] = 'LATIN1';
	$lang['applangdir'] = 'ltr';

	// Basic strings
	$lang['strintro'] = 'Bienvenue sur phpPgAdmin.';
	$lang['strppahome'] = 'Page d\'accueil phpPgAdmin';
	$lang['strpgsqlhome'] = 'Page d\'accueil PostgreSQL';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL Documentation (local)';
	$lang['strreportbug'] = 'Rapporter un Bug';
	$lang['strviewfaq'] = 'Voir la FAQ';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = 'Login';
	$lang['strloginfailed'] = 'Echec de la connexion';
        $lang['strlogindisallowed']  =  'Login dsactiv pour scurit';
	$lang['strserver'] = 'Serveur';
	$lang['strlogout'] = 'Dconnexion';
	$lang['strowner'] = 'Propritaire';
	$lang['straction'] = 'Action';
	$lang['stractions'] = 'Actions';
	$lang['strname'] = 'Nom';
	$lang['strdefinition'] = 'Dfinition';
	$lang['strproperties'] = 'Proprits';
	$lang['strbrowse'] = 'Parcourir';
	$lang['strdrop'] = 'Supprimer';
	$lang['strdropped'] = 'Supprim';
	$lang['strnull'] = 'Null';
	$lang['strnotnull'] = 'Not Null';
	$lang['strprev'] = 'Prcdent';
	$lang['strnext'] = 'Suivant';
        $lang['strfirst'] = '<< Dbut';
	$lang['strlast'] = 'Fin >>';
        $lang['strfailed']  =  'Echec';
	$lang['strcreate'] = 'Crer';
	$lang['strcreated'] = 'Cr';
	$lang['strcomment'] = 'Commentaire';
	$lang['strlength'] = 'Longueur';
	$lang['strdefault'] = 'Defaut';
	$lang['stralter'] = 'Modifier';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'Annuler';
	$lang['strsave'] = 'Sauvegarder';
	$lang['strreset'] = 'Rinitialiser';
	$lang['strinsert'] = 'Insrer';
	$lang['strselect'] = 'Selectionner';
	$lang['strdelete'] = 'Effacer';
	$lang['strupdate'] = 'Modifier';
	$lang['strreferences'] = 'Rfrences';
	$lang['stryes'] = 'Oui';
	$lang['strno'] = 'Non';
	$lang['strtrue'] = 'TRUE';
	$lang['strfalse'] = 'FALSE';
        $lang['stredit']  =  'Editer';
        $lang['strcolumn']  =  'Colonne';
	$lang['strcolumns'] = 'Colonnes';
	$lang['strrows'] = 'ligne(s)';
	$lang['strrowsaff'] = 'ligne(s) affecte(s).';
        $lang['strobjects']  =  'objet(s)';
        $lang['strexample']  =  'exple.';
	$lang['strback'] = 'Retour';
	$lang['strqueryresults'] = 'Rsultats de la requte';
	$lang['strshow'] = 'Voir';
	$lang['strempty'] = 'Vider';
	$lang['strlanguage'] = 'Langage';
	$lang['strencoding'] = 'Codage';
	$lang['strvalue'] = 'Valeur';
	$lang['strunique'] = 'Unique';
	$lang['strprimary'] = 'Primaire';
	$lang['strexport'] = 'Exporter';
	$lang['strimport'] = 'Import';
        $lang['strsql']  =  'SQL';
	$lang['strgo'] = 'Go';
	$lang['stradmin'] = 'Admin';
	$lang['strvacuum'] = 'Vacuum';
	$lang['stranalyze'] = 'Analyze';
	$lang['strcluster'] = 'Cluster';
        $lang['strclustered']  =  'En Cluster ?';
	$lang['strreindex'] = 'Reindex';
	$lang['strrun'] = 'Lancer';
	$lang['stradd'] = 'Ajouter';
	$lang['strevent'] = 'Evnement';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = 'Do Instead';
	$lang['strwhen'] = 'When';
	$lang['strformat'] = 'Format';
	$lang['strdata'] = 'Donne';
	$lang['strconfirm'] = 'Confirmer';
	$lang['strexpression'] = 'Expression';
	$lang['strellipsis'] = '...';
        $lang['strseparator']  =  ': ';
	$lang['strexpand'] = 'Etendre';
	$lang['strcollapse'] = 'Rduire';
	$lang['strexplain'] = 'Explain';
        $lang['strexplainanalyze']  =  'Explain Analyze';
	$lang['strfind'] = 'Rechercher';
	$lang['stroptions'] = 'Options';
	$lang['strrefresh'] = 'Raffraichir';
	$lang['strdownload'] = 'Tlcharger';
        $lang['strdownloadgzipped']  =  'Tlcharger avec compression gzip';
        $lang['strinfo']  =  'Info';
        $lang['stroids']  =  'OIDs';
        $lang['stradvanced']  =  'Avanc';
        $lang['strvariables']  =  'Variables';
        $lang['strprocess']  =  'Processus';
        $lang['strprocesses']  =  'Processus';
        $lang['strsetting']  =  'Paramtrage';
        $lang['streditsql']  =  'Editer SQL';
        $lang['strruntime']  =  'Temps d\'execution Total: %s ms';
        $lang['strpaginate']  =  'Paginer les rsultats';
        $lang['struploadscript']  =  'ou importer un script SQL :';
        $lang['strstarttime']  =  'Heure de Dpart';
        $lang['strfile']  =  'Fichier';
        $lang['strfileimported']  =  'Fichier import.';

	// Error handling
	$lang['strnoframes'] = 'Vous avez besoin d\'activer les frames de votre navigateur pour utiliser cette application.';
	$lang['strbadconfig'] = 'Le fichier de configuration config.inc.php est obsolte. Vous avez besoin de le regnerer  partir de config.inc.php-dist.';
	$lang['strnotloaded'] = 'Vous n\'avez pas compil correctement le support de la base de donnes dans votre installation de PHP.';
        $lang['strphpversionnotsupported']  =  'Cette version de PHP n\'est pas supporte. Merci de mettre  jour PHP  la  version  %s ou ultrieure.';
        $lang['strpostgresqlversionnotsupported']  =  'Cette Version de PostgreSQL n\'est pas supporte. Merci de mettre  jour PHP  la version %s ou ultrieure.';
	$lang['strbadschema'] = 'Schma spcifi invalide.';
	$lang['strbadencoding'] = 'Impossible de spcifier l\'encodage de la base de donnes.';
	$lang['strsqlerror'] = 'Erreur SQL :';
	$lang['strinstatement'] = 'In statement:';
	$lang['strinvalidparam'] = 'Paramtres de script invalides.';
	$lang['strnodata'] = 'Pas de Rsultats.';
        $lang['strnoobjects']  =  'Aucun objet trouv.';
	$lang['strrownotunique'] = 'Pas d\identifiant unique pour cette ligne.';
        $lang['strnoreportsdb']  =  'Vous n\'avez pas crer des rapports de la base de Donnes. Lisez le fichier INSTALL pour voir les directives.';
        $lang['strnouploads']  =  'Importation de fichiers dsactiv.';
        $lang['strimporterror']  =  'Erreur d\'importation.';
        $lang['strimporterrorline']  =  'Erreur d\'importation  la ligne %s.';

	// Tables
	$lang['strtable'] = 'Table';
	$lang['strtables'] = 'Tables';
	$lang['strshowalltables'] = 'Voir toutes les tables';
	$lang['strnotables'] = 'Aucune table trouve.';
	$lang['strnotable'] = 'Aucune table trouve.';
	$lang['strcreatetable'] = 'Crer une table';
	$lang['strtablename'] = 'Nom de la table';
	$lang['strtableneedsname'] = 'Vous devez donner un nom pour votre table.';
	$lang['strtableneedsfield'] = 'Vous devez spcifier au moins un champ.';
	$lang['strtableneedscols'] = 'Vous devez indiquer un nombre valide de colonnes.';
	$lang['strtablecreated'] = 'Table cre.';
	$lang['strtablecreatedbad'] = 'Echec de la cration de table.';
	$lang['strconfdroptable'] = 'Etes-vous sur de vouloir supprimer la table "%s"?';
	$lang['strtabledropped'] = 'Table supprime.';
	$lang['strtabledroppedbad'] = 'Echec de la suppresion de table.';
	$lang['strconfemptytable'] = 'Etes-vous sr de vouloir vider la table "%s"?';
	$lang['strtableemptied'] = 'Table vide.';
	$lang['strtableemptiedbad'] = 'Echec du vidage de la table.';
	$lang['strinsertrow'] = 'Inserer enregistrement.';
	$lang['strrowinserted'] = 'Enregistrement insr.';
	$lang['strrowinsertedbad'] = 'Echec d\'insertion d\'un enregistrement.';
	$lang['streditrow'] = 'Editer enregistrement.';
	$lang['strrowupdated'] = 'Enregistrement mis  jour.';
	$lang['strrowupdatedbad'] = 'Echec de mise  jour de l\'enregistrement.';
	$lang['strdeleterow'] = 'Effacer enregistrement';
	$lang['strconfdeleterow'] = 'Etes-vous sr de vouloir supprimer cet enregistrement ?';
	$lang['strrowdeleted'] = 'Enregistrement Supprim.';
	$lang['strrowdeletedbad'] = 'Echec de suppression de l\'enregistrement.';
        $lang['strinsertandrepeat']  =  'Inserer & Repeter';
        $lang['strnumcols']  =  'Nombre de colonnes';
        $lang['strcolneedsname']  =  'Vous devez spcifier un nom pour la colonne';
	$lang['strselectallfields'] = 'Slectionner tous les champs';
        $lang['strselectneedscol']  =  'Vous devez slectionner au moins une colonne.';
        $lang['strselectunary']  =  'Oprateurs unaires ne peuvent avoir de valeurs.';
	$lang['straltercolumn'] = 'Modifier colonne';
	$lang['strcolumnaltered'] = 'Colonne modifie.';
	$lang['strcolumnalteredbad'] = 'Echec de modification de la colonne.';
        $lang['strconfdropcolumn'] = 'Etes-vous sr de vouloir supprimer la colonne "%s" de la table "%s"?';
	$lang['strcolumndropped'] = 'Colonne supprime.';
	$lang['strcolumndroppedbad'] = 'Echec de suppression de la colonne.';
	$lang['straddcolumn'] = 'Ajouter une colonne';
	$lang['strcolumnadded'] = 'Colonne ajoute.';
	$lang['strcolumnaddedbad'] = 'Echec d\'ajout de colonne.';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = 'Table modifie.';
	$lang['strtablealteredbad'] = 'Echec  la modification de la table.';
        $lang['strdataonly']  =  'Donnes seulement';
        $lang['strstructureonly']  =  'Structure seulement';
        $lang['strstructureanddata']  =  'Structure et donnes';
        $lang['strtabbed']  =  'Tabul';
        $lang['strauto']  =  'Auto';
        $lang['strconfvacuumtable']  =  'Etes-vous sur de vouloir faire un  vacuum "%s"?';
        $lang['strestimatedrowcount']  =  'Nombre d\'enregistrements estims';

	// Users
	$lang['struser'] = 'Utilisateur';
	$lang['strusers'] = 'Utilisateurs';
	$lang['strusername'] = 'Utilisateur';
	$lang['strpassword'] = 'Mot de passe';
	$lang['strsuper'] = 'Super Utilisateur ?';
	$lang['strcreatedb'] = 'Crer base de donnes?';
	$lang['strexpires'] = 'Expiration';
        $lang['strsessiondefaults']  =  'Session par dfaut';
	$lang['strnousers'] = 'Aucun utilisateur trouv.';
	$lang['struserupdated'] = 'Utilisateur mis  jour.';
	$lang['struserupdatedbad'] = 'Echec de mise  jour de l\'utilisateur.';
	$lang['strshowallusers'] = 'Voir tous les utilisateurs';
	$lang['strcreateuser'] = 'Crer un utilisateur';
        $lang['struserneedsname']  =  'Vous devez donner un nom pour votre utilisateur.';
	$lang['strusercreated'] = 'Utilisateur Cr.';
	$lang['strusercreatedbad'] = 'Echec de cration de l\'utilisateur.';
	$lang['strconfdropuser'] = 'Etes-vous sr de vouloir supprimer l\'utilisateur "%s"?';
	$lang['struserdropped'] = 'Utilisateur supprim.';
	$lang['struserdroppedbad'] = 'Echec de suppression de l\'utilisateur.';
	$lang['straccount'] = 'Comptes';
        $lang['strchangepassword'] = 'Modifier le mot de passe';
	$lang['strpasswordchanged'] = 'Mot de passe modifi.';
	$lang['strpasswordchangedbad'] = 'Echec  la modification du mot de passe.';
	$lang['strpasswordshort'] = 'Le mot de passe est trop court.';
	$lang['strpasswordconfirm'] = 'Le mot de passe de confirmation est diffrent.';
	
	// Groups
	$lang['strgroup'] = 'Groupe';
	$lang['strgroups'] = 'Groupes';
	$lang['strnogroup'] = 'Groupe non trouv.';
	$lang['strnogroups'] = 'Aucun groupe trouv.';
	$lang['strcreategroup'] = 'Crer un groupe';
	$lang['strshowallgroups'] = 'Voir tous les groupes';
	$lang['strgroupneedsname'] = 'Vous devez indiquer un nom pour votre groupe.';
	$lang['strgroupcreated'] = 'Groupe cr.';
	$lang['strgroupcreatedbad'] = 'Echec de cration du groupe.';	
	$lang['strconfdropgroup'] = 'Etes vous sr de vouloir supprimer le groupe "%s"?';
	$lang['strgroupdropped'] = 'Groupe supprim.';
	$lang['strgroupdroppedbad'] = 'Echec de suppression du groupe.';
	$lang['strmembers'] = 'Membres';
	$lang['straddmember'] = 'Ajouter un membre';
	$lang['strmemberadded'] = 'Membre ajout.';
	$lang['strmemberaddedbad'] = 'Echec pendant l\'ajout de membre.';
	$lang['strdropmember'] = 'Supprimer un membre';
	$lang['strconfdropmember'] = 'Etes-vous sur de vouloir supprimer le membre "%s" pour le groupe "%s"?';
	$lang['strmemberdropped'] = 'Membre supprim.';
	$lang['strmemberdroppedbad'] = 'Echec  la suppression de membre.';
	// Privilges
	$lang['strprivilege'] = 'Privilge';
	$lang['strprivileges'] = 'Privilges';
	$lang['strnoprivileges'] = 'Cet objet n\'a pas de privilges.';
	$lang['strgrant'] = 'Accorder(Grant)';
	$lang['strrevoke'] = 'Rvoquer';
	$lang['strgranted'] = 'Privilges accords.';
	$lang['strgrantfailed'] = 'Echec de l\'octroi de privilges.';

	$lang['strgrantbad'] = 'Vous devez spcifier au moins un utilisateur ou groupe et au moins un privilge.';
	$lang['strgrantor'] = 'Grantor';
	$lang['strasterisk'] = '*';
	// Databases
	$lang['strdatabase'] = 'Base de Donnes';
	$lang['strdatabases'] = 'Bases de Donnes';
	$lang['strshowalldatabases'] = 'Voir toutes les bases de donnes';
	$lang['strnodatabase'] = 'Aucune base de donnes trouve.';
	$lang['strnodatabases'] = 'Aucune base de donnes trouve.';
	$lang['strcreatedatabase'] = 'Crer une base de donnes';
	$lang['strdatabasename'] = 'Nom de la base de donnes';
	$lang['strdatabaseneedsname'] = 'Vous devez donner un nom pour votre base de donnes.';
	$lang['strdatabasecreated'] = 'Base de Donnes cre.';
	$lang['strdatabasecreatedbad'] = 'Echec de cration de la base de donnes.';	
	$lang['strconfdropdatabase'] = 'Etes-vous sr de vouloir supprimer la base de donnes "%s"?';
	$lang['strdatabasedropped'] = 'Base de donnes supprime.';
	$lang['strdatabasedroppedbad'] = 'Echec de suppression de la base de donnes.';
	$lang['strentersql'] = 'Veuillez saisir ci-dessous la requte SQL  excuter :';
	$lang['strsqlexecuted'] = 'Reguete SQL excute.';
        $lang['strvacuumgood']  =  'Vacuum excut.';
	$lang['strvacuumbad'] = 'Echec du Vacuum.';
	$lang['stranalyzegood'] = 'Analyse effectue.';
	$lang['stranalyzebad'] = 'Echec de l\'analyse.';
        $lang['strreindexgood']  =  'Rindexation excute.';
        $lang['strreindexbad']  =  'Echec de la Rindexation.';
        $lang['strfull']  =  'Intgral(Full)';
        $lang['strfreeze']  =  'Freeze';
        $lang['strforce']  =  'Forcer';
        $lang['strsignalsent']  =  'Signal envoy.';
        $lang['strsignalsentbad']  =  'Echec  l\'Envoi du signal.';
        $lang['strallobjects']  =  'Tous les objets';

	// Views
	$lang['strview'] = 'Vue';
	$lang['strviews'] = 'Vues';
	$lang['strshowallviews'] = 'Voir toutes les vues';
	$lang['strnoview'] = 'Aucne vue trouve.';
	$lang['strnoviews'] = 'Aucune vue trouve.';
	$lang['strcreateview'] = 'Crer une vue';
	$lang['strviewname'] = 'Nom de la vue';
	$lang['strviewneedsname'] = 'Vous devez indiquer un nom pour votre vue.';
	$lang['strviewneedsdef'] = 'Vous devez indiquer une dfinition pour votre vue.';
        $lang['strviewneedsfields']  =  'Vous devez prciser les colonnes que vous voulez slectionner dans votre vue.';
	$lang['strviewcreated'] = 'Vue cre.';
	$lang['strviewcreatedbad'] = 'Echec de cration de la vue.';
	$lang['strconfdropview'] = 'Ete-vous sr de vouloir supprimer la vue "%s"?';
	$lang['strviewdropped'] = 'Vue supprime.';
	$lang['strviewdroppedbad'] = 'Echec de suppression de la vue.';
	$lang['strviewupdated'] = 'Vue mise  jour.';
	$lang['strviewupdatedbad'] = 'Echec de mise  jour de la vue.';
        $lang['strviewlink']  =  'Cls Lies';
        $lang['strviewconditions']  =  'Conditions Additionnelles';
        $lang['strcreateviewwiz']  =  'Crer une vue avec l\'assistant';

	// Sequences
	$lang['strsequence'] = 'Squence';
	$lang['strsequences'] = 'Squences';
	$lang['strshowallsequences'] = 'Voir toutes les squences';
	$lang['strnosequence'] = 'Aucune squence trouve.';
	$lang['strnosequences'] = 'Aucune squence trouve.';
	$lang['strcreatesequence'] = 'Crer une squence';
	$lang['strlastvalue'] = 'Dernire valeur';
	$lang['strincrementby'] = 'Incrmenter par ';	
	$lang['strstartvalue'] = 'Valeur de dpart';
	$lang['strmaxvalue'] = 'Valeur maxilale';
	$lang['strminvalue'] = 'Valeur minimale';
	$lang['strcachevalue'] = 'Valeur de cache';
	$lang['strlogcount'] = 'Log Count';
	$lang['striscycled'] = 'Est Cycle?';
	$lang['striscalled'] = 'Est Appele?';
	$lang['strsequenceneedsname'] = 'Vous devez spcifier un nom pour votre squence.';
	$lang['strsequencecreated'] = 'Squence cre.';
	$lang['strsequencecreatedbad'] = 'Echec de cration de la squence.'; 
	$lang['strconfdropsequence'] = 'Etes vous sur de vouloir supprimer la squence "%s"?';
	$lang['strsequencedropped'] = 'Squence supprime.';
	$lang['strsequencedroppedbad'] = 'Echec de suppression de la squence.';

	$lang['strsequencereset'] = 'Sequence initialise.';
	$lang['strsequenceresetbad'] = 'Echec de l\'initialisation de la squence.';
	// Indexes
	$lang['strindex']  =  'Index';
	$lang['strindexes'] = 'Index';
	$lang['strindexname'] = 'Nom de l\'index';
	$lang['strshowallindexes'] = 'Voir tous les index';
	$lang['strnoindex'] = 'Aucun index trouv.';
	$lang['strnoindexes'] = 'Aucun index trouv.';
	$lang['strcreateindex'] = 'Crer un index';
	$lang['strtabname'] = 'Nom de la table';
	$lang['strcolumnname'] = 'Nom de la colonne';
	$lang['strindexneedsname'] = 'Vous devez indiquer un nom pour votre index';
	$lang['strindexneedscols'] = 'Vous devez indiquer un nombre valide de colonnes.';
	$lang['strindexcreated'] = 'Index cr';
	$lang['strindexcreatedbad'] = 'Echec de cration de l\'index.';
	$lang['strconfdropindex'] = 'Etes-vous sr de vouloir supprimer l\'index "%s"?';
	$lang['strindexdropped'] = 'Index supprim.';
	$lang['strindexdroppedbad'] = 'Echec de suppression de l\'index.';
	$lang['strkeyname'] = 'Nom de la cl';
	$lang['struniquekey'] = 'Cl unique';
	$lang['strprimarykey'] = 'Cl primaire';
 	$lang['strindextype'] = 'Type d\'index';
	$lang['strtablecolumnlist'] = 'Liste des colonnes';
	$lang['strindexcolumnlist'] = 'Liste des colonnes dans l\'index';
        $lang['strconfcluster']  =  'Etes vous sur de vouloir mettre en cluster "%s"?';
        $lang['strclusteredgood']  =  'Cluster effectu.';
        $lang['strclusteredbad']  =  'Echec du Cluster.';

	// Rules
	$lang['strrules'] = 'Rgles';
	$lang['strrule'] = 'Rgle';
	$lang['strshowallrules'] = 'Voir toutes les rgles';
	$lang['strnorule'] = 'Aucune rgle trouve.';
	$lang['strnorules'] = 'Aucune rgle trouve.';
	$lang['strcreaterule'] = 'Crer une rgle';
	$lang['strrulename'] = 'Nom de la rgle';
	$lang['strruleneedsname'] = 'Vous devez indiquer un nom pour votre rgle.';
	$lang['strrulecreated'] = 'Rgle cre.';
	$lang['strrulecreatedbad'] = 'Echec de cration de la rgle.';
	$lang['strconfdroprule'] = 'Etes-vous sr de vouloir supprimer la rgle "%s" sur "%s"?';
	$lang['strruledropped'] = 'Rgle supprime.';
	$lang['strruledroppedbad'] = 'Echec de suppression de rgle.';

	// Constraints
	$lang['strconstraints'] = 'Contraintes';
	$lang['strshowallconstraints'] = 'Voir toutes les contraintes';
	$lang['strnoconstraints'] = 'Aucune contrainte trouve.';
	$lang['strcreateconstraint'] = 'Crer une contrainte';
	$lang['strconstraintcreated'] = 'Cration d\'une contrainte.';
	$lang['strconstraintcreatedbad'] = 'Echec de cration de la contrainte.';
	$lang['strconfdropconstraint'] = 'Etes vous sr de vouloir supprimer la contrainte "%s" sur "%s"?';
	$lang['strconstraintdropped'] = 'Contrainte supprime.';
	$lang['strconstraintdroppedbad'] = 'Echec de suppression de la contrainte.';
	$lang['straddcheck'] = 'Ajouter une Contrainte';
	$lang['strcheckneedsdefinition'] = 'La Contrainte a besoin d\'une dfinition.';
	$lang['strcheckadded'] = 'Contrainte ajoute.';
        $lang['strcheckaddedbad']  =  'Echec pour l\'ajout d\une contrainte check.';
	$lang['straddpk'] = 'Ajouter une cl primaire';
	$lang['strpkneedscols'] = 'La cl primaire ncessite au moins une colonne.';
	$lang['strpkadded'] = 'Primary key added.';
	$lang['strpkaddedbad'] = 'Echec lors de l\'ajout de la cl primaire.';
	$lang['stradduniq'] = 'Ajouter une cl Unique';
	$lang['struniqneedscols'] = 'Une Cl Unique ncessite au moins une colonne.';
	$lang['struniqadded'] = 'La Cl unique a t rajoute.';
	$lang['struniqaddedbad'] = 'Echec lors de la cration de la cl Unique.';
	$lang['straddfk'] = 'Ajouter une cl Etrangre';
	$lang['strfkneedscols'] = 'Une Cl Etrangre ncessite au moins une colonne.';
	$lang['strfkneedstarget'] = 'Une cl Etrangre ncessite une table Cible.';
	$lang['strfkadded'] = 'La Cl Etrangre a t rajoute.';
	$lang['strfkaddedbad'] = 'Echec lors de la cration de la cl Etrangre.';
	$lang['strfktarget'] = 'Table Cible';
	$lang['strfkcolumnlist'] = 'Liste des Colonnes de la cl';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';

	// Functions
	$lang['strfunction'] = 'Fonction';
	$lang['strfunctions'] = 'Fonctions';
	$lang['strshowallfunctions'] = 'Voir toutes les fonctions';
	$lang['strnofunction'] = 'Aucune fonction trouve.';
	$lang['strnofunctions'] = 'Aucune Fonction trouve.';
	$lang['strcreateplfunction']  =  'Crer une fonction PL/SQL';
        $lang['strcreateinternalfunction']  =  'Crer une fonction interne';
        $lang['strcreatecfunction']  =  'Crer une fonction C';
	$lang['strfunctionname'] = 'Nom de la fonction';
	$lang['strreturns'] = 'Valeur de sortie';
	$lang['strarguments'] = 'Arguments';
	$lang['strproglanguage'] = 'Langage';
	$lang['strfunctionneedsname'] = 'Vous devez indiquer un nom pour votre fonction.';
	$lang['strfunctionneedsdef'] = 'Vous devez indiquer une dfinition pour votre fonction.';
	$lang['strfunctioncreated'] = 'Fonction cre.';
	$lang['strfunctioncreatedbad'] = 'Echec de cration de la fonction.';
	$lang['strconfdropfunction'] = 'Etes-vous sr de vouloir supprimer la fonction "%s"?';
	$lang['strfunctiondropped'] = 'Fonction supprime.';
	$lang['strfunctiondroppedbad'] = 'Echech de suppression de la fonction.';
	$lang['strfunctionupdated'] = 'Fonction mise  jour.';
	$lang['strfunctionupdatedbad'] = 'Echec de mise  jour de la fonction.';
        $lang['strobjectfile']  =  'Fichier Objet';
        $lang['strlinksymbol']  =  'Symbole Lien';

	// Triggers
	$lang['strtrigger'] = 'Trigger';
	$lang['strtriggers'] = 'Triggers';
	$lang['strshowalltriggers'] = 'Voir tous les triggers';
	$lang['strnotrigger'] = 'Aucun trigger trouv.';
	$lang['strnotriggers'] = 'Aucun trigger trouv.';
	$lang['strcreatetrigger'] = 'Crer un trigger';
	$lang['strtriggerneedsname'] = 'Vous devez indiquer un nom pour votre trigger.';
	$lang['strtriggerneedsfunc'] = 'Vous devez indiquer une fonction pour votre trigger.';
	$lang['strtriggercreated'] = 'Trigger cr.';
	$lang['strtriggercreatedbad'] = 'Echec de cration du trigger.';
	$lang['strconfdroptrigger'] = 'Etes-vous sr de vouloir supprimer le trigger "%s" sur "%s"?';
	$lang['strtriggerdropped'] = 'Trigger supprim.';
        $lang['strtriggerdroppedbad']  =  'Echec lors de la suppression du trigger.';
	$lang['strtriggeraltered'] = 'Trigger modifi.';
	$lang['strtriggeralteredbad'] = 'Echec lors de la modification du Trigger.';

	// Types
	$lang['strtype'] = 'Type';
	$lang['strtypes'] = 'Types';
	$lang['strshowalltypes'] = 'Voir tous les types';
	$lang['strnotype'] = 'Aucun type trouv.';
	$lang['strnotypes'] = 'Aucun type trouv.';
	$lang['strcreatetype'] = 'Crer un type';
        $lang['strcreatecomptype']  =  'Crer un type compos';
        $lang['strtypeneedsfield']  =  'Vous devez spcifier au moins un champ.';
        $lang['strtypeneedscols']  =  'Vous devez spcifier un nombre valide de champs.';	
	$lang['strtypename'] = 'Nom du type';
	$lang['strinputfn'] = 'Fonction d\'entre';
	$lang['stroutputfn'] = 'Fonction de sortie';
	$lang['strpassbyval'] = 'Passe par valeur?';
	$lang['stralignment'] = 'Alignement';
	$lang['strelement'] = 'Elment';
	$lang['strdelimiter'] = 'Dlimiteur';
	$lang['strstorage'] = 'Stockage';
        $lang['strfield']  =  'Champ';
        $lang['strnumfields']  =  'Nbre. de Champs';
	$lang['strtypeneedsname'] = 'Vous devez indiquer un nom pour votre type.';
	$lang['strtypeneedslen'] = 'Vous devez indiquer une longueur pour votre type.';
	$lang['strtypecreated'] = 'Type cr';
	$lang['strtypecreatedbad'] = 'Echec de cration du type.';
	$lang['strconfdroptype'] = 'Etes-vous sr de vouloir supprim le type "%s"?';
	$lang['strtypedropped'] = 'Type supprim.';
	$lang['strtypedroppedbad'] = 'Echec de suppression du type.';
        $lang['strflavor']  =  'Flavor';
	$lang['strbasetype']  =  'Base';
	$lang['strcompositetype']  =  'Composite';
	$lang['strpseudotype']  =  'Pseudo';

	// Schemas
	$lang['strschema'] = 'Schma';
	$lang['strschemas'] = 'Schmas';
	$lang['strshowallschemas'] = 'Voir Tous les schmas';
	$lang['strnoschema'] = 'Aucun schma trouv.';
	$lang['strnoschemas'] = 'Aucun schma trouv.';
	$lang['strcreateschema'] = 'Crer un schma';
	$lang['strschemaname'] = 'Nom du schma';
	$lang['strschemaneedsname'] = 'Vous devez indiquer un nom pour votre schma.';
	$lang['strschemacreated'] = 'Schma cr';
	$lang['strschemacreatedbad'] = 'Echec de cration du schma.';
	$lang['strconfdropschema'] = 'Etes-vous sr de vouloir supprimer le schma "%s"?';
	$lang['strschemadropped'] = 'Schma supprim.';
	$lang['strschemadroppedbad'] = 'Echec de suppression du schma.';
        $lang['strschemaaltered']  =  'Schema altered.';
        $lang['strschemaalteredbad']  =  'Schema alter failed.';
        $lang['strsearchpath']  =  'Chemin de Recherche du Schema';

	// Reports
	$lang['strreport'] = 'Rapport';
	$lang['strreports'] = 'Rapports';
	$lang['strshowallreports'] = 'Voir tous les rapports';
	$lang['strnoreports'] = 'Aucun rapport trouv.';
	$lang['strcreatereport'] = 'Crer un rapport';
	$lang['strreportdropped'] = 'Rapport supprim.';
	$lang['strreportdroppedbad'] = 'Echec de suppression du rapport.';
	$lang['strconfdropreport'] = 'Etes-vous sur de vouloir supprimer le rapport "%s"?';
	$lang['strreportneedsname'] = 'Vous devez indiquer un nom pour votre rapport.';
	$lang['strreportneedsdef'] = 'Vous devez fournir une requte SQL pour votre rapport.';
	$lang['strreportcreated'] = 'Rapport sauvegard.';
	$lang['strreportcreatedbad'] = 'Echec de sauvegarde du rapport.';

        // Domains
	$lang['strdomain'] = 'Domaine';
	$lang['strdomains'] = 'Domaines';
	$lang['strshowalldomains'] = 'Voir tous les domaines';
	$lang['strnodomains'] = 'Pas de domaine trouv.';
	$lang['strcreatedomain'] = 'Crer un domaine';
	$lang['strdomaindropped'] = 'Domaine supprim.';
	$lang['strdomaindroppedbad'] = 'Echec de la suppression.';
	$lang['strconfdropdomain'] = 'Etes vous sur de vouloir supprimer le domaine "%s"?';
	$lang['strdomainneedsname'] = 'Vous devez donner un nom pour votre domaine.';
	$lang['strdomaincreated'] = 'Domaine cr.';
	$lang['strdomaincreatedbad'] = 'Echec  la cration du domaine.';	
	$lang['strdomainaltered'] = 'Domaine modifi.';
	$lang['strdomainalteredbad'] = 'Echec  la modification du domaine.';	

	// Operators
	$lang['stroperator'] = 'Operateur';
	$lang['stroperators'] = 'Operateurs';
	$lang['strshowalloperators'] = 'Voir tous les oprateurs';
	$lang['strnooperator'] = 'Pas d\'oprateur trouv.';
	$lang['strnooperators'] = 'Pas d\'oprateur trouv.';
	$lang['strcreateoperator'] = 'Crer un oprateur';
	$lang['strleftarg'] = 'Type de l\'argument de gauche';
	$lang['strrightarg'] = 'Type de l\'argument de droite';
	$lang['strcommutator'] = 'Commutateur';
	$lang['strnegator'] = 'Negator';
	$lang['strrestrict'] = 'Restrict';
	$lang['strjoin'] = 'Join';
	$lang['strhashes'] = 'Hashes';
	$lang['strmerges'] = 'Merges';
	$lang['strleftsort'] = 'Left sort';
	$lang['strrightsort'] = 'Right sort';
	$lang['strlessthan'] = 'Plus petit que';
	$lang['strgreaterthan'] = 'Plus grand que';
        $lang['stroperatorneedsname']  =  'Vous devez donner un nom pour votre oprateur.';
        $lang['stroperatorcreated']  =  'Operateur cr';
        $lang['stroperatorcreatedbad']  =  'Echec lors de la cration de l\'oprateur.';
        $lang['strconfdropoperator']  =  'Etes vous sur de vouloir supprimer l\'oprateur "%s"?';
        $lang['stroperatordropped']  =  'Oprateur supprim.';
        $lang['stroperatordroppedbad']  =  'Echec lors de la suppression de l\'oprateur.';

	// Casts
	$lang['strcasts'] = 'Casts';
	$lang['strnocasts'] = 'No casts found.';
	$lang['strsourcetype'] = 'Source type';
	$lang['strtargettype'] = 'Target type';
	$lang['strimplicit'] = 'Implicit';
	$lang['strinassignment'] = 'In assignment';
	$lang['strbinarycompat'] = '(Binary compatible)';
	
	// Conversions
	$lang['strconversions'] = 'Conversions';
	$lang['strnoconversions'] = 'Pas de Conversion trouv.';
	$lang['strsourceencoding'] = 'Source encoding';
	$lang['strtargetencoding'] = 'Target encoding';
	
	// Languages
	$lang['strlanguages'] = 'Langages';
	$lang['strnolanguages'] = 'Pas de langage trouv.';
	$lang['strtrusted'] = 'Trusted';
	
	// Info
	$lang['strnoinfo'] = 'Pas d\'information disponible.';
	$lang['strreferringtables'] = 'Referring tables';
	$lang['strparenttables'] = 'Tables Parents';
	$lang['strchildtables'] = 'Tables Enfants';
	
	// Aggregates
	$lang['straggregates']  =  'Aggregats';
	$lang['strnoaggregates']  =  'Pas d\'aggregat trouv.';
        $lang['stralltypes']  =  '(Tous les types)';

	// Operator Classes
        $lang['stropclasses']  =  'Classes d\'oprateur';
     	$lang['strnoopclasses']  =  'Aucune classe d\'oprateur trouve.';
	$lang['straccessmethod']  =  'Mthode d\'accs';

	// Stats and performance
	$lang['strrowperf']  =  'Performance de l\'Enregistrement';
	$lang['strioperf']  =  'Performance Entre/Sortie';
	$lang['stridxrowperf']  =  'Performance Index';
	$lang['stridxioperf']  =  'Performance Index Entres/Sortie';
	$lang['strpercent']  =  '%';
	$lang['strsequential']  =  'Sequentiel';
	$lang['strscan']  =  'Scan';
	$lang['strread']  =  'Lire';
	$lang['strfetch']  =  'Fetch';
	$lang['strheap']  =  'Heap';
        $lang['strtoast']  =  'TOAST';
	$lang['strtoastindex']  =  'TOAST Index';
	$lang['strcache']  =  'Cache';
	$lang['strdisk']  =  'Disque';
	$lang['strrows2']  =  'Enregistrements';

	// Tablespaces
	$lang['strtablespace']  =  'Tablespace';
	$lang['strtablespaces']  =  'Tablespaces';
	$lang['strshowalltablespaces']  =  'Voir tous les tablespaces';
	$lang['strnotablespaces']  =  'Pas de tablespaces trouv.';
	$lang['strcreatetablespace']  =  'Crer un tablespace';
	$lang['strlocation']  =  'Location';
	$lang['strtablespaceneedsname']  =  'Vous devez donner un nom  votre tablespace.';
	$lang['strtablespaceneedsloc']  =  'Vous devez prciser un rpertoire dans lequel sera cr le tablespace.';
	$lang['strtablespacecreated']  =  'Tablespace cr.';
	$lang['strtablespacecreatedbad']  =  'Echec  la cration du Tablespace.';
	$lang['strconfdroptablespace']  =  'Etes vous sur de vouloir supprimer le tablespace "%s"?';
	$lang['strtablespacedropped']  =  'Tablespace supprim.';
	$lang['strtablespacedroppedbad']  =  'Echec  la suppression du tablespace.';
	$lang['strtablespacealtered']  =  'Tablespace modifi.';
	$lang['strtablespacealteredbad']  =  'Echec  la modification du Tablespace.';

	// Miscellaneous
	$lang['strtopbar']  =  '%s lanc sur %s:%s -- Vous tes connect avec le profil  "%s", %s';
	$lang['strtimefmt']  =  'jS M, Y g:iA';
	$lang['strhelp']  =  'Aide';
$lang['strhelpicon']  =  '?';

?>
